/****************************************************************************
** QgsNorthArrowPluginGuiBase meta object code from reading C++ file 'pluginguibase.h'
**
** Created: Fri Nov 4 14:26:06 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "pluginguibase.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsNorthArrowPluginGuiBase::className() const
{
    return "QgsNorthArrowPluginGuiBase";
}

QMetaObject *QgsNorthArrowPluginGuiBase::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsNorthArrowPluginGuiBase( "QgsNorthArrowPluginGuiBase", &QgsNorthArrowPluginGuiBase::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsNorthArrowPluginGuiBase::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsNorthArrowPluginGuiBase", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsNorthArrowPluginGuiBase::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsNorthArrowPluginGuiBase", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsNorthArrowPluginGuiBase::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QDialog::staticMetaObject();
    static const QUMethod slot_0 = {"pbnOK_clicked", 0, 0 };
    static const QUMethod slot_1 = {"pbnCancel_clicked", 0, 0 };
    static const QUParameter param_slot_2[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_2 = {"sliderRotation_valueChanged", 1, param_slot_2 };
    static const QUParameter param_slot_3[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_3 = {"sliderRotation_sliderMoved", 1, param_slot_3 };
    static const QUParameter param_slot_4[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_4 = {"spinSize_valueChanged", 1, param_slot_4 };
    static const QUParameter param_slot_5[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_5 = {"cboxShow_toggled", 1, param_slot_5 };
    static const QUParameter param_slot_6[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_6 = {"cboPlacement_textChanged", 1, param_slot_6 };
    static const QUMethod slot_7 = {"languageChange", 0, 0 };
    static const QMetaData slot_tbl[] = {
	{ "pbnOK_clicked()", &slot_0, QMetaData::Public },
	{ "pbnCancel_clicked()", &slot_1, QMetaData::Public },
	{ "sliderRotation_valueChanged(int)", &slot_2, QMetaData::Public },
	{ "sliderRotation_sliderMoved(int)", &slot_3, QMetaData::Public },
	{ "spinSize_valueChanged(int)", &slot_4, QMetaData::Public },
	{ "cboxShow_toggled(bool)", &slot_5, QMetaData::Public },
	{ "cboPlacement_textChanged(const QString&)", &slot_6, QMetaData::Public },
	{ "languageChange()", &slot_7, QMetaData::Protected }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsNorthArrowPluginGuiBase", parentObject,
	slot_tbl, 8,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsNorthArrowPluginGuiBase.setMetaObject( metaObj );
    return metaObj;
}

void* QgsNorthArrowPluginGuiBase::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsNorthArrowPluginGuiBase" ) )
	return this;
    return QDialog::qt_cast( clname );
}

bool QgsNorthArrowPluginGuiBase::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: pbnOK_clicked(); break;
    case 1: pbnCancel_clicked(); break;
    case 2: sliderRotation_valueChanged((int)static_QUType_int.get(_o+1)); break;
    case 3: sliderRotation_sliderMoved((int)static_QUType_int.get(_o+1)); break;
    case 4: spinSize_valueChanged((int)static_QUType_int.get(_o+1)); break;
    case 5: cboxShow_toggled((bool)static_QUType_bool.get(_o+1)); break;
    case 6: cboPlacement_textChanged((const QString&)static_QUType_QString.get(_o+1)); break;
    case 7: languageChange(); break;
    default:
	return QDialog::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsNorthArrowPluginGuiBase::qt_emit( int _id, QUObject* _o )
{
    return QDialog::qt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES

bool QgsNorthArrowPluginGuiBase::qt_property( int id, int f, QVariant* v)
{
    return QDialog::qt_property( id, f, v);
}

bool QgsNorthArrowPluginGuiBase::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
